summaryrefslogtreecommitdiff
path: root/x11-clocks/wmtz/files/patch-ac
blob: e807d454173fb4116548efbdfb6f1e32603c35e3 (plain) (blame)
1
2
3
4
5
6
7
8
9
10
11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
--- wmtz.c.orig	Thu Nov 20 22:04:56 2003
+++ wmtz.c	Thu Nov 20 22:06:57 2003
@@ -51,7 +51,7 @@
 #define STRSIZE 10
 #define LMST 1
 #define GMST 0
-#define ABOUT "xmessage -center -buttons \"Close\" \"WMTZ - Window Maker Time Zone dockapp v0.7
+#define ABOUT "xmessage -center -buttons \"Close\" \"WMTZ - Window Maker Time Zone dockapp v0.7\n\
 http://www.geocities.com/jl1n/wmtz/wmtz.html\""
 
 
@@ -275,15 +275,15 @@
 
         if (!Read_Config_File(config_file))
         {
             /* Fall back to /etc/wmtzrc */
             free(config_file);
             config_file = malloc( 12 );
             if (config_file == NULL)
                 errH(1, 1, "malloc");
 
-            sprintf(config_file, "/etc/wmtzrc");
+            sprintf(config_file, "${PREFIX}/etc/wmtzrc ");
             
-            fprintf(stderr, "Using /etc/wmtzrc as config file.\n");
+            fprintf(stderr, "Using ${PREFIX}/etc/wmtzrc as config file.\n");
         
             Read_Config_File(config_file);
         }
@@ -479,6 +479,7 @@
 		   but_stat = -1;
                    break;
 	    default:
+		;
 	  }
         }  
 
@@ -529,6 +530,7 @@
 	    exit(0);
 	    break;
 	default:
+	    ;
       }
     return;
 }
@@ -729,7 +731,8 @@
 void usage(void)
 {
   fprintf(stderr, "\nwmtz - shows local time around the world and more.\n");
-  fprintf(stderr, "See ~/.wmtzrc or /etc/wmtzrc for configuration.\n\n");
+  fprintf(stderr, "See ~/.wmtzrc or ${PREFIX}/etc/wmtzrc.default for\n");
+  fprintf(stderr, "configuration.\n\n");
   fprintf(stderr, "Usage:\n");
   fprintf(stderr, "    -display <display name>\n");
   fprintf(stderr, "    -e <editor>               use specified editor\n");
@@ -275,15 +275,15 @@
         if (!Read_Config_File(config_file))
         {
-            /* Fall back to /etc/wmtzrc */
+            /* Fall back to ${PREFIX}/etc/wmtzrc */
             free(config_file);
             config_file = malloc( 12 );